processorhelperprofiles

package module
v0.116.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 16, 2024 License: Apache-2.0 Imports: 1 Imported by: 2

Documentation

Overview

Deprecated: [0.116.0] Use go.opentelemetry.io/collector/processor/processorhelper/xprocessorhelper instead.

Deprecated: [0.116.0] Use go.opentelemetry.io/collector/processor/processorhelper/xprocessorhelper instead.

Index

Constants

This section is empty.

Variables

NewProfiles creates a xprocessor.Profiles that ensure context propagation. Deprecated: [0.116.0] Use xprocessorhelper.NewProfiles instead.

WithCapabilities overrides the default GetCapabilities function for an processor. The default GetCapabilities function returns mutable capabilities. Deprecated: [0.116.0] Use xprocessorhelper.WithCapabilities instead.

WithShutdown overrides the default Shutdown function for an processor. The default shutdown function does nothing and always returns nil. Deprecated: [0.116.0] Use xprocessorhelper.WithShutdown instead.

WithStart overrides the default Start function for an processor. The default shutdown function does nothing and always returns nil. Deprecated: [0.116.0] Use xprocessorhelper.WithStart instead.

Functions

This section is empty.

Types

type Option

type Option = xprocessorhelper.Option

Option apply changes to internalOptions. Deprecated: [0.116.0] Use xprocessorhelper.Option instead.

type ProcessProfilesFunc

type ProcessProfilesFunc = xprocessorhelper.ProcessProfilesFunc

ProcessProfilesFunc is a helper function that processes the incoming data and returns the data to be sent to the next component. If error is returned then returned data are ignored. It MUST not call the next component. Deprecated: [0.116.0] Use xprocessorhelper.ProcessProfilesFunc instead.

Jump to